# mautrix-twitter
![Languages](https://img.shields.io/github/languages/top/tulir/mautrix-twitter.svg)
[![License](https://img.shields.io/github/license/tulir/mautrix-twitter.svg)](LICENSE)
[![Release](https://img.shields.io/github/release/tulir/mautrix-twitter/all.svg)](https://github.com/tulir/mautrix-twitter/releases)
[![GitLab CI](https://mau.dev/tulir/mautrix-twitter/badges/master/pipeline.svg)](https://mau.dev/tulir/mautrix-twitter/container_registry)

A Matrix-Twitter DM puppeting bridge.

### [Wiki](https://github.com/tulir/mautrix-twitter/wiki)

### [Features & Roadmap](https://github.com/tulir/mautrix-twitter/blob/master/ROADMAP.md)

## Discussion
Matrix room: [`#twitter:maunium.net`](https://matrix.to/#/#twitter:maunium.net)
